==> side_menu_v3.4.1.zip: side_menu/l10n/ru.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Custom menu",
    "Enable the custom menu": "Включить пользовательское меню",
    "No": "Нет",
    "Yes": "Да",
    "Menu": "Меню",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Используйте сочетание клавиш <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span>, чтобы открыть или скрыть боковое меню. Используйте <span class=\"keyboard-key\">Tab<\/span> для навигации.",
    "Top menu": "Верхнее меню",
    "Apps that not must be moved in the side menu": "Приложения не перемещаемые в боковое меню",
    "If there is no selection then the global configuration is applied.": "If there is no selection then the global configuration is applied.",
    "Experimental": "Экспериментальный",
    "Save": "Сохранить",
    "You like this app and you want to support me?": "Вам нравится приложение или вы хотите поддержать меня?",
    "Buy me a coffee ☕": "Купить мне чашку кофе ☕",
    "Hidden": "Скрыто",
    "Small": "Маленький",
    "Normal": "Средний",
    "Big": "Большой",
    "Hidden icon": "Скрытая иконка",
    "Small icon": "Маленькая иконка",
    "Normal icon": "Средняя иконка",
    "Big icon": "Большая иконка",
    "Hidden text": "Скрытый текст",
    "Small text": "Маленький текст",
    "Normal text": "Средний текст",
    "Big text": "Большой текст",
    "Colors": "Цвета",
    "Background color": "Цвет фона",
    "Background color of current app": "Цвет фона выбранного приложения",
    "Text color": "Цвет текста",
    "Loader": "Загрузчик",
    "Icon": "Иконка",
    "Same color": "Такой же цвет",
    "Opposite color": "Opposite color",
    "Transparent": "Прозрачный",
    "Opaque": "Opaque",
    "Opener": "Opener",
    "Default": "По-умолчанию",
    "Default (dark)": "По-умолчанию (тёмный)",
    "Hamburger": "Гамбургер",
    "Hamburger (dark)": "Гамбургер (тёмный)",
    "Hamburger 2": "Гамбургер 2",
    "Hamburger 2 (dark)": "Гамбургер 2 (тёмный)",
    "Before the logo": "Перед логотипом",
    "After the logo": "После логотипа",
    "Position": "Позиция",
    "Show only the opener (hidden logo)": "Show only the opener (hidden logo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Do not display the side menu and the opener if there is no application (eg: public pages).",
    "Panel": "Панеот",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)",
    "Display the big menu": "Отобразить большое меню",
    "Display the logo": "Показать лого",
    "Icons and texts": "Иконки и текст",
    "Loader enabled": "Loader enabled",
    "Tips": "Советы",
    "Always displayed": "Всегда отображается",
    "This is the automatic behavior when the menu is always displayed.": "This is the automatic behavior when the menu is always displayed.",
    "Not compatible with touch screens.": "Не совместимо с сенсорными экранами",
    "Big menu": "Большое меню",
    "Live preview": "Live preview",
    "Open apps in new tab": "Открывать приложения в новой вкладке",
    "Use the global setting": "Use the global setting",
    "Use my selection": "Use my selection",
    "Show and hide the list of applications": "Показать или скрыть список приложений",
    "Use the avatar instead of the logo": "Использовать аватар вместо логотипа",
    "You do not have permission to change the settings.": "У вас нет разрешения изменять настройки",
    "Force this configuration to users": "Force this configuration to users",
    "Export the configuration": "Экспортировать конфигурацию",
    "Purge the cache": "Очистить кэш",
    "Show the link to settings": "Показать ссылку на настройки",
    "The menu is enabled by default for users": "The menu is enabled by default for users",
    "Except when the configuration is forced.": "Except when the configuration is forced.",
    "Apps that should not be displayed in the menu": "Apps that should not be displayed in the menu",
    "This feature is only compatible with the <code>big menu<\/code> display.": "This feature is only compatible with the <code>big menu<\/code> display.",
    "The logo is a link to the default app": "The logo is a link to the default app",
    "Others": "Прочие",
    "Categories": "Категории",
    "Customize sorting": "Настроить сортировку",
    "Order by": "В порядке",
    "Name": "Название",
    "Customed": "Customed",
    "Show and hide the list of categories": "Показать или скрыть список категорий",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "This parameters are used when Dark theme or Breeze Dark Theme are enabled.",
    "Dark mode colors": "Цвета тёмной темы",
    "With categories": "С категориями",
    "Custom categories": "Custom categories",
    "Customize application categories": "Customize application categories",
    "Reset to default": "Сбросить к значениям по-умолчанию",
    "Applications": "Приложения",
    "Applications kept in the top menu": "Applications kept in the top menu",
    "Applications kept in the top menu but also shown in side menu": "Applications kept in the top menu but also shown in side menu",
    "These applications must be selected in the previous option.": "These applications must be selected in the previous option."
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v3.7.4.zip: side_menu/l10n/ru.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Custom menu",
    "Enable the custom menu": "Включить пользовательское меню",
    "No": "Нет",
    "Yes": "Да",
    "Menu": "Меню",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Используйте сочетание клавиш <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span>, чтобы открыть или скрыть боковое меню. Используйте <span class=\"keyboard-key\">Tab<\/span> для навигации.",
    "Top menu": "Верхнее меню",
    "Apps that not must be moved in the side menu": "Приложения не перемещаемые в боковое меню",
    "If there is no selection then the global configuration is applied.": "Если тут ничего не отмечено, применяются глобальные настройки.",
    "Experimental": "Экспериментальный",
    "Save": "Сохранить",
    "You like this app and you want to support me?": "Вам нравится приложение или вы хотите поддержать меня?",
    "Buy me a coffee ☕": "Купить мне чашку кофе ☕",
    "Hidden": "Скрыто",
    "Small": "Маленький",
    "Normal": "Средний",
    "Big": "Большой",
    "Hidden icon": "Без иконки",
    "Small icon": "Маленькая иконка",
    "Normal icon": "Средняя иконка",
    "Big icon": "Большая иконка",
    "Hidden text": "Без текста",
    "Small text": "Маленький текст",
    "Normal text": "Средний текст",
    "Big text": "Большой текст",
    "Colors": "Цвета",
    "Background color": "Цвет фона",
    "Background color of current app": "Цвет фона выбранного приложения",
    "Text color": "Цвет текста",
    "Loader": "Загрузчик",
    "Icon": "Иконка",
    "Same color": "Такой же цвет",
    "Opposite color": "Противоположный цвет",
    "Transparent": "Прозрачный",
    "Opaque": "Непрозрачный",
    "Opener": "Открывалка",
    "Default": "По умолчанию",
    "Default (dark)": "По умолчанию (тёмный)",
    "Hamburger": "Гамбургер",
    "Hamburger (dark)": "Гамбургер (тёмный)",
    "Hamburger 2": "Гамбургер 2",
    "Hamburger 2 (dark)": "Гамбургер 2 (тёмный)",
    "Before the logo": "Перед логотипом",
    "After the logo": "После логотипа",
    "Position": "Положение",
    "Show only the opener (hidden logo)": "Показать только открывающую часть (скрытый логотип)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Не отображать боковое меню и открывалку, если нет приложения (например, публичные страницы).",
    "Panel": "Панель",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Открывать меню при наведении мыши на экран (автоматически отключается на сенсорных экранах)",
    "Display the big menu": "Отобразить большое меню",
    "Display the logo": "Показать логотип",
    "Icons and texts": "Иконки и текст",
    "Loader enabled": "Загрузчик включен",
    "Tips": "Советы",
    "Always displayed": "Всегда отображается",
    "This is the automatic behavior when the menu is always displayed.": "This is the automatic behavior when the menu is always displayed.",
    "Not compatible with touch screens.": "Не совместимо с сенсорными экранами.",
    "Big menu": "Большое меню",
    "Live preview": "Live preview",
    "Open apps in new tab": "Открывать приложения в новой вкладке",
    "Use the global setting": "Использовать глобальные настройки",
    "Use my selection": "Использовать мои настройки",
    "Show and hide the list of applications": "Показать или скрыть список приложений",
    "Use the avatar instead of the logo": "Использовать аватар вместо логотипа",
    "You do not have permission to change the settings.": "У вас нет разрешения изменять настройки.",
    "Force this configuration to users": "Force this configuration to users",
    "Export the configuration": "Экспортировать конфигурацию",
    "Purge the cache": "Очистить кэш",
    "Show the link to settings": "Показать ссылку на настройки",
    "The menu is enabled by default for users": "Это меню включено по умолчанию для пользователей",
    "Except when the configuration is forced.": "Except when the configuration is forced.",
    "Apps that should not be displayed in the menu": "Ппрограммы, скрытые из меню",
    "This feature is only compatible with the <code>big menu<\/code> display.": "This feature is only compatible with the <code>big menu<\/code> display.",
    "The logo is a link to the default app": "Логотип открывает приложение по умолчанию",
    "Others": "Прочие",
    "Categories": "Категории",
    "Customize sorting": "Настроить сортировку",
    "Order by": "В порядке",
    "Name": "Название",
    "Customed": "Customed",
    "Show and hide the list of categories": "Показать или скрыть список категорий",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "Эти настройки используются темами Тёмная и Тёмная Breeze.",
    "Dark mode colors": "Цвета тёмной темы",
    "With categories": "С категориями",
    "Custom categories": "Пользовательские категории",
    "Customize application categories": "Изменить категории приложений",
    "Reset to default": "Сбросить к значениям по умолчанию",
    "Applications": "Приложения",
    "Applications kept in the top menu": "Applications kept in the top menu",
    "Applications kept in the top menu but also shown in side menu": "Applications kept in the top menu but also shown in side menu",
    "These applications must be selected in the previous option.": "These applications must be selected in the previous option.",
    "Hide labels on mouse over": "Скрыть название при наведении мыши"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
